#!/usr/bin/env python
#
# Data Quality Checker also known as DQC
#
# Read the README.md for more detailed information
#
#       Barcelona Supercomputing Center - Centro Nacional de Supercomputacion
#       Earth Sciences Department - Computational Earth Sciences
#     
#     Authors: 
#       Joan Sala Calero (joan.sala@bsc.es)
#       Ivan Jose Cernicharo Ortiz (ivan.cernicharo@bsc.es)

import os
import logging
from datetime import date

def list_files_folder(path):
    list_files = []
    if os.path.exists(path):
        if os.path.isfile(path) and path.endswith("grib") or path.endswith("nc") or path.endswith("grb"):
            list_files.append(path) 
        if os.path.isdir(path) or os.path.isfile(path):
            for root, dirs, files in os.walk(path):                
                for f in files:
                    if f.endswith("grib") or f.endswith("nc") or f.endswith("grb"):
                        list_files.append(os.path.join(root,f))
        
            return sorted(list_files)

        else:
            raise Exception('\n\tGiven path is not a valid path\n')

def dir_or_file(path):
    if os.path.isfile(path):
        print("INFO: Checking file")
        print(path)
        # do the file checking
        return [path]

    elif os.path.isdir(path):        
        # list all files in the folder
        list_files = list_files_folder(path)        
        print("INFO: Path {}".format(path))
        print("INFO: Found {} files to check".format(len(list_files)))
        
        if len(list_files):
            print("INFO: [1]: {}".format(os.path.basename(list_files[0])))
            print("INFO: [N]: {}".format(os.path.basename(list_files[-1])))
        else:
            raise Exception('No files found for analysis')

        return list_files            
       
def initiate_logging(path_logs, path_files, testid):

    # Directory check
    if not os.path.exists(path_logs):
        os.makedirs(path_logs)

    # Log file name
    default_log_name = '_'.join(
        [
            'LOG',
            testid,
            date.today().strftime('%Y%m%d'),
            '.txt'
        ]
    )
    default_path = os.path.join(path_logs, default_log_name)
    print('INFO: Saving log in {}'.format(default_path))
    
    # Logging configuration
    logging.basicConfig(
        filename=default_path,
        format='%(levelname)s:%(asctime)s:%(message)s', 
        level=logging.INFO
    )

    # Write header
    stringA = '\n' + '#'*80 + '\n' + '#'*80
    stringA += '\n RUNNING TEST {} FOR FOLDER:'.format(testid)
    stringA += '\n ' + path_files
    stringA += '\n' + '#'*80
    logging.info(stringA)